==> openshift-model-miscellaneous-6.6.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/ProvisionStatusFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ProvisionStatusFluent<A extends ProvisionStatusFluent<A>> extends Fluent<A>{
  public String getId();
  public A withId(String id);
  public Boolean hasId();
  public String getBootMode();
  public A withBootMode(String bootMode);
  public Boolean hasBootMode();
  
  /**
   * This method has been deprecated, please use method buildCustomDeploy instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomDeploy getCustomDeploy();
  public CustomDeploy buildCustomDeploy();
  public A withCustomDeploy(CustomDeploy customDeploy);
  public Boolean hasCustomDeploy();
  public A withNewCustomDeploy(String method);
  public ProvisionStatusFluent.CustomDeployNested<A> withNewCustomDeploy();
  public ProvisionStatusFluent.CustomDeployNested<A> withNewCustomDeployLike(CustomDeploy item);
  public ProvisionStatusFluent.CustomDeployNested<A> editCustomDeploy();
  public ProvisionStatusFluent.CustomDeployNested<A> editOrNewCustomDeploy();
  public ProvisionStatusFluent.CustomDeployNested<A> editOrNewCustomDeployLike(CustomDeploy item);
  
  /**
   * This method has been deprecated, please use method buildFirmware instead.
   * @return The buildable object.
   */
  @Deprecated
  public FirmwareConfig getFirmware();
  public FirmwareConfig buildFirmware();
  public A withFirmware(FirmwareConfig firmware);
  public Boolean hasFirmware();
  public A withNewFirmware(Boolean simultaneousMultithreadingEnabled,Boolean sriovEnabled,Boolean virtualizationEnabled);
  public ProvisionStatusFluent.FirmwareNested<A> withNewFirmware();
  public ProvisionStatusFluent.FirmwareNested<A> withNewFirmwareLike(FirmwareConfig item);
  public ProvisionStatusFluent.FirmwareNested<A> editFirmware();
  public ProvisionStatusFluent.FirmwareNested<A> editOrNewFirmware();
  public ProvisionStatusFluent.FirmwareNested<A> editOrNewFirmwareLike(FirmwareConfig item);
  
  /**
   * This method has been deprecated, please use method buildImage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Image getImage();
  public Image buildImage();
  public A withImage(Image image);
  public Boolean hasImage();
  public A withNewImage(String checksum,String checksumType,String format,String url);
  public ProvisionStatusFluent.ImageNested<A> withNewImage();
  public ProvisionStatusFluent.ImageNested<A> withNewImageLike(Image item);
  public ProvisionStatusFluent.ImageNested<A> editImage();
  public ProvisionStatusFluent.ImageNested<A> editOrNewImage();
  public ProvisionStatusFluent.ImageNested<A> editOrNewImageLike(Image item);
  
  /**
   * This method has been deprecated, please use method buildRaid instead.
   * @return The buildable object.
   */
  @Deprecated
  public RAIDConfig getRaid();
  public RAIDConfig buildRaid();
  public A withRaid(RAIDConfig raid);
  public Boolean hasRaid();
  public ProvisionStatusFluent.RaidNested<A> withNewRaid();
  public ProvisionStatusFluent.RaidNested<A> withNewRaidLike(RAIDConfig item);
  public ProvisionStatusFluent.RaidNested<A> editRaid();
  public ProvisionStatusFluent.RaidNested<A> editOrNewRaid();
  public ProvisionStatusFluent.RaidNested<A> editOrNewRaidLike(RAIDConfig item);
  
  /**
   * This method has been deprecated, please use method buildRootDeviceHints instead.
   * @return The buildable object.
   */
  @Deprecated
  public RootDeviceHints getRootDeviceHints();
  public RootDeviceHints buildRootDeviceHints();
  public A withRootDeviceHints(RootDeviceHints rootDeviceHints);
  public Boolean hasRootDeviceHints();
  public ProvisionStatusFluent.RootDeviceHintsNested<A> withNewRootDeviceHints();
  public ProvisionStatusFluent.RootDeviceHintsNested<A> withNewRootDeviceHintsLike(RootDeviceHints item);
  public ProvisionStatusFluent.RootDeviceHintsNested<A> editRootDeviceHints();
  public ProvisionStatusFluent.RootDeviceHintsNested<A> editOrNewRootDeviceHints();
  public ProvisionStatusFluent.RootDeviceHintsNested<A> editOrNewRootDeviceHintsLike(RootDeviceHints item);
  public String getState();
  public A withState(String state);
  public Boolean hasState();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CustomDeployNested<N> extends Nested<N>,CustomDeployFluent<ProvisionStatusFluent.CustomDeployNested<N>>{
    public N and();
    public N endCustomDeploy();
    
  }
  public interface FirmwareNested<N> extends Nested<N>,FirmwareConfigFluent<ProvisionStatusFluent.FirmwareNested<N>>{
    public N and();
    public N endFirmware();
    
  }
  public interface ImageNested<N> extends Nested<N>,ImageFluent<ProvisionStatusFluent.ImageNested<N>>{
    public N and();
    public N endImage();
    
  }
  public interface RaidNested<N> extends Nested<N>,RAIDConfigFluent<ProvisionStatusFluent.RaidNested<N>>{
    public N and();
    public N endRaid();
    
  }
  public interface RootDeviceHintsNested<N> extends Nested<N>,RootDeviceHintsFluent<ProvisionStatusFluent.RootDeviceHintsNested<N>>{
    public N and();
    public N endRootDeviceHints();
    
  }
  
}

==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/ProvisionStatusFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ProvisionStatusFluent<A extends ProvisionStatusFluent<A>> extends Fluent<A>{
  public String getId();
  public A withId(String id);
  public Boolean hasId();
  public String getBootMode();
  public A withBootMode(String bootMode);
  public Boolean hasBootMode();
  
  /**
   * This method has been deprecated, please use method buildCustomDeploy instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomDeploy getCustomDeploy();
  public CustomDeploy buildCustomDeploy();
  public A withCustomDeploy(CustomDeploy customDeploy);
  public Boolean hasCustomDeploy();
  public A withNewCustomDeploy(String method);
  public ProvisionStatusFluent.CustomDeployNested<A> withNewCustomDeploy();
  public ProvisionStatusFluent.CustomDeployNested<A> withNewCustomDeployLike(CustomDeploy item);
  public ProvisionStatusFluent.CustomDeployNested<A> editCustomDeploy();
  public ProvisionStatusFluent.CustomDeployNested<A> editOrNewCustomDeploy();
  public ProvisionStatusFluent.CustomDeployNested<A> editOrNewCustomDeployLike(CustomDeploy item);
  
  /**
   * This method has been deprecated, please use method buildFirmware instead.
   * @return The buildable object.
   */
  @Deprecated
  public FirmwareConfig getFirmware();
  public FirmwareConfig buildFirmware();
  public A withFirmware(FirmwareConfig firmware);
  public Boolean hasFirmware();
  public A withNewFirmware(Boolean simultaneousMultithreadingEnabled,Boolean sriovEnabled,Boolean virtualizationEnabled);
  public ProvisionStatusFluent.FirmwareNested<A> withNewFirmware();
  public ProvisionStatusFluent.FirmwareNested<A> withNewFirmwareLike(FirmwareConfig item);
  public ProvisionStatusFluent.FirmwareNested<A> editFirmware();
  public ProvisionStatusFluent.FirmwareNested<A> editOrNewFirmware();
  public ProvisionStatusFluent.FirmwareNested<A> editOrNewFirmwareLike(FirmwareConfig item);
  
  /**
   * This method has been deprecated, please use method buildImage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Image getImage();
  public Image buildImage();
  public A withImage(Image image);
  public Boolean hasImage();
  public A withNewImage(String checksum,String checksumType,String format,String url);
  public ProvisionStatusFluent.ImageNested<A> withNewImage();
  public ProvisionStatusFluent.ImageNested<A> withNewImageLike(Image item);
  public ProvisionStatusFluent.ImageNested<A> editImage();
  public ProvisionStatusFluent.ImageNested<A> editOrNewImage();
  public ProvisionStatusFluent.ImageNested<A> editOrNewImageLike(Image item);
  
  /**
   * This method has been deprecated, please use method buildRaid instead.
   * @return The buildable object.
   */
  @Deprecated
  public RAIDConfig getRaid();
  public RAIDConfig buildRaid();
  public A withRaid(RAIDConfig raid);
  public Boolean hasRaid();
  public ProvisionStatusFluent.RaidNested<A> withNewRaid();
  public ProvisionStatusFluent.RaidNested<A> withNewRaidLike(RAIDConfig item);
  public ProvisionStatusFluent.RaidNested<A> editRaid();
  public ProvisionStatusFluent.RaidNested<A> editOrNewRaid();
  public ProvisionStatusFluent.RaidNested<A> editOrNewRaidLike(RAIDConfig item);
  
  /**
   * This method has been deprecated, please use method buildRootDeviceHints instead.
   * @return The buildable object.
   */
  @Deprecated
  public RootDeviceHints getRootDeviceHints();
  public RootDeviceHints buildRootDeviceHints();
  public A withRootDeviceHints(RootDeviceHints rootDeviceHints);
  public Boolean hasRootDeviceHints();
  public ProvisionStatusFluent.RootDeviceHintsNested<A> withNewRootDeviceHints();
  public ProvisionStatusFluent.RootDeviceHintsNested<A> withNewRootDeviceHintsLike(RootDeviceHints item);
  public ProvisionStatusFluent.RootDeviceHintsNested<A> editRootDeviceHints();
  public ProvisionStatusFluent.RootDeviceHintsNested<A> editOrNewRootDeviceHints();
  public ProvisionStatusFluent.RootDeviceHintsNested<A> editOrNewRootDeviceHintsLike(RootDeviceHints item);
  public String getState();
  public A withState(String state);
  public Boolean hasState();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CustomDeployNested<N> extends Nested<N>,CustomDeployFluent<ProvisionStatusFluent.CustomDeployNested<N>>{
    public N and();
    public N endCustomDeploy();
    
  }
  public interface FirmwareNested<N> extends Nested<N>,FirmwareConfigFluent<ProvisionStatusFluent.FirmwareNested<N>>{
    public N and();
    public N endFirmware();
    
  }
  public interface ImageNested<N> extends Nested<N>,ImageFluent<ProvisionStatusFluent.ImageNested<N>>{
    public N and();
    public N endImage();
    
  }
  public interface RaidNested<N> extends Nested<N>,RAIDConfigFluent<ProvisionStatusFluent.RaidNested<N>>{
    public N and();
    public N endRaid();
    
  }
  public interface RootDeviceHintsNested<N> extends Nested<N>,RootDeviceHintsFluent<ProvisionStatusFluent.RootDeviceHintsNested<N>>{
    public N and();
    public N endRootDeviceHints();
    
  }
  
}
